@@ -155,7 +155,7 @@ psutil_proc_kill(PyObject *self, PyObject *args)
     hProcess = OpenProcess(PROCESS_TERMINATE, FALSE, pid);
     if (hProcess == NULL) {
         if (GetLastError() == ERROR_INVALID_PARAMETER) {
-            // see http://code.google.com/p/psutil/issues/detail?id=24
+            // see https://github.com/giampaolo/psutil/issues/24
             NoSuchProcess();
         }
         else {
@@ -172,8 +172,7 @@ psutil_proc_kill(PyObject *self, PyObject *args)
     }
 
     CloseHandle(hProcess);
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -202,8 +201,7 @@ psutil_proc_wait(PyObject *self, PyObject *args)
         if (GetLastError() == ERROR_INVALID_PARAMETER) {
             // no such process; we do not want to raise NSP but
             // return None instead.
-            Py_INCREF(Py_None);
-            return Py_None;
+            Py_RETURN_NONE;
         }
         else {
             PyErr_SetFromWindowsErr(0);
@@ -439,8 +437,7 @@ psutil_cpu_count_logical(PyObject *self, PyObject *args)
     GetSystemInfo(&system_info);
     if (system_info.dwNumberOfProcessors == 0) {
         // mimic os.cpu_count()
-        Py_INCREF(Py_None);
-        return Py_None;
+        Py_RETURN_NONE;
     }
     else {
         return Py_BuildValue("I", system_info.dwNumberOfProcessors);
@@ -510,8 +507,7 @@ return_none:
     // mimic os.cpu_count()
     if (buffer != NULL)
         free(buffer);
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -573,13 +569,7 @@ psutil_proc_exe(PyObject *self, PyObject *args) {
     }
     if (GetProcessImageFileNameW(hProcess, &exe, MAX_PATH) == 0) {
         CloseHandle(hProcess);
-        if (GetLastError() == ERROR_INVALID_PARAMETER) {
-            // see https://code.google.com/p/psutil/issues/detail?id=414
-            AccessDenied();
-        }
-        else {
-            PyErr_SetFromWindowsErr(0);
-        }
+        PyErr_SetFromWindowsErr(0);
         return NULL;
     }
     CloseHandle(hProcess);
@@ -1085,8 +1075,7 @@ psutil_proc_suspend(PyObject *self, PyObject *args)
     if (! psutil_proc_suspend_or_resume(pid, suspend)) {
         return NULL;
     }
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -1102,8 +1091,7 @@ psutil_proc_resume(PyObject *self, PyObject *args)
     if (! psutil_proc_suspend_or_resume(pid, suspend)) {
         return NULL;
     }
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -1410,7 +1398,8 @@ psutil_proc_username(PyObject *self, PyObject *args)
     memcpy(&fullName[domainNameSize + 1], name, nameSize);
     fullName[domainNameSize + 1 + nameSize] = '\0';
 
-    returnObject = Py_BuildValue("s", fullName);
+    returnObject = PyUnicode_Decode(
+        fullName, _tcslen(fullName), Py_FileSystemDefaultEncoding, "replace");
 
     free(fullName);
     free(name);
@@ -1991,8 +1980,7 @@ psutil_proc_priority_set(PyObject *self, PyObject *args)
         PyErr_SetFromWindowsErr(0);
         return NULL;
     }
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -2067,8 +2055,7 @@ psutil_proc_io_priority_set(PyObject *self, PyObject *args)
     );
 
     CloseHandle(hProcess);
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 #endif
 
@@ -2192,8 +2179,7 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
     }
 
     CloseHandle(hProcess);
-    Py_INCREF(Py_None);
-    return Py_None;
+    Py_RETURN_NONE;
 }
 
 
@@ -2274,8 +2260,9 @@ static PyObject *
 psutil_net_io_counters(PyObject *self, PyObject *args)
 {
     int attempts = 0;
+    int i;
     int outBufLen = 15000;
-    char ifname[2000];
+    char ifname[MAX_PATH];
     DWORD dwRetVal = 0;
     MIB_IFROW *pIfRow = NULL;
     ULONG flags = 0;
@@ -2333,7 +2320,7 @@ psutil_net_io_counters(PyObject *self, PyObject *args)
             goto error;
         }
 
-        py_nic_info = Py_BuildValue("(IIIIIIII)",
+        py_nic_info = Py_BuildValue("(kkkkkkkk)",
                                     pIfRow->dwOutOctets,
                                     pIfRow->dwInOctets,
                                     pIfRow->dwOutUcastPkts,
@@ -2346,7 +2333,9 @@ psutil_net_io_counters(PyObject *self, PyObject *args)
             goto error;
 
         sprintf(ifname, "%wS", pCurrAddresses->FriendlyName);
-        py_nic_name = Py_BuildValue("s", ifname);
+        py_nic_name = PyUnicode_Decode(
+            ifname, _tcslen(ifname), Py_FileSystemDefaultEncoding, "replace");
+
         if (py_nic_name == NULL)
             goto error;
         if (PyDict_SetItem(py_retdict, py_nic_name, py_nic_info))
@@ -2373,7 +2362,7 @@ error:
 }
 
 // fix for mingw32, see
-// https://code.google.com/p/psutil/issues/detail?id=351#c2
+// https://github.com/giampaolo/psutil/issues/351#c2
 typedef struct _DISK_PERFORMANCE_WIN_2008 {
     LARGE_INTEGER BytesRead;
     LARGE_INTEGER BytesWritten;
@@ -2426,13 +2415,13 @@ psutil_disk_io_counters(PyObject *self, PyObject *args)
         {
             sprintf(szDeviceDisplay, "PhysicalDrive%d", devNum);
             py_disk_info = Py_BuildValue(
-                "(IILLLL)",
+                "(IILLKK)",
                 diskPerformance.ReadCount,
                 diskPerformance.WriteCount,
                 diskPerformance.BytesRead,
                 diskPerformance.BytesWritten,
-                (diskPerformance.ReadTime.QuadPart * 10) / 1000,
-                (diskPerformance.WriteTime.QuadPart * 10) / 1000);
+                (unsigned long long)(diskPerformance.ReadTime.QuadPart * 10) / 1000,
+                (unsigned long long)(diskPerformance.WriteTime.QuadPart * 10) / 1000);
             if (!py_disk_info)
                 goto error;
             if (PyDict_SetItemString(py_retdict, szDeviceDisplay,
@@ -2515,7 +2504,7 @@ psutil_disk_partitions(PyObject *self, PyObject *args)
     }
 
     // avoid to visualize a message box in case something goes wrong
-    // see http://code.google.com/p/psutil/issues/detail?id=264
+    // see https://github.com/giampaolo/psutil/issues/264
     SetErrorMode(SEM_FAILCRITICALERRORS);
 
     if (! PyArg_ParseTuple(args, "O", &py_all)) {
@@ -2646,6 +2635,8 @@ psutil_users(PyObject *self, PyObject *args)
     PyObject *py_retlist = PyList_New(0);
     PyObject *py_tuple = NULL;
     PyObject *py_address = NULL;
+    PyObject *py_buffer_user_encoded = NULL;
+
     if (py_retlist == NULL) {
         return NULL;
     }
@@ -2730,12 +2721,16 @@ psutil_users(PyObject *self, PyObject *args)
             station_info.ConnectTime.dwLowDateTime - 116444736000000000LL;
         unix_time /= 10000000;
 
-        py_tuple = Py_BuildValue("sOd", buffer_user, py_address,
+        py_buffer_user_encoded = PyUnicode_Decode(
+            buffer_user, _tcslen(buffer_user), Py_FileSystemDefaultEncoding,
+            "replace");
+        py_tuple = Py_BuildValue("OOd", py_buffer_user_encoded, py_address,
                                  (double)unix_time);
         if (!py_tuple)
             goto error;
         if (PyList_Append(py_retlist, py_tuple))
             goto error;
+        Py_XDECREF(py_buffer_user_encoded);
         Py_XDECREF(py_address);
         Py_XDECREF(py_tuple);
     }
@@ -2748,6 +2743,7 @@ psutil_users(PyObject *self, PyObject *args)
     return py_retlist;
 
 error:
+    Py_XDECREF(py_buffer_user_encoded);
     Py_XDECREF(py_tuple);
     Py_XDECREF(py_address);
     Py_DECREF(py_retlist);
@@ -3167,6 +3163,8 @@ void init_psutil_windows(void)
         INITERROR;
     }
 
+    PyModule_AddIntConstant(module, "version", PSUTIL_VERSION);
+
     // process status constants
     // http://msdn.microsoft.com/en-us/library/ms683211(v=vs.85).aspx
     PyModule_AddIntConstant(
@@ -3223,4 +3221,4 @@ void init_psutil_windows(void)
 #if PY_MAJOR_VERSION >= 3
     return module;
 #endif
-}
+}
\ No newline at end of file
